package com.solution.system.mapper;

import java.util.List;
import com.solution.system.domain.Behaviortree;

/**
 * 行为树主Mapper接口
 * 
 * @author ruoyi
 * @date 2026-02-05
 */
public interface BehaviortreeMapper 
{
    /**
     * 查询行为树主
     * 
     * @param id 行为树主主键
     * @return 行为树主
     */
    public Behaviortree selectBehaviortreeById(Long id);

    /**
     * 查询行为树主列表
     * 
     * @param behaviortree 行为树主
     * @return 行为树主集合
     */
    public List<Behaviortree> selectBehaviortreeList(Behaviortree behaviortree);

    /**
     * 新增行为树主
     * 
     * @param behaviortree 行为树主
     * @return 结果
     */
    public int insertBehaviortree(Behaviortree behaviortree);

    /**
     * 修改行为树主
     * 
     * @param behaviortree 行为树主
     * @return 结果
     */
    public int updateBehaviortree(Behaviortree behaviortree);

    /**
     * 删除行为树主
     * 
     * @param id 行为树主主键
     * @return 结果
     */
    public int deleteBehaviortreeById(Long id);

    /**
     * 批量删除行为树主
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBehaviortreeByIds(Long[] ids);
}
